geolocate.classes.arguments module — Geolocate 1.3.0 documentation

# geolocate.classes.arguments module

Geolocate argument parser module.

Programmed by: Dante Signal31

email: dante.signal31@gmail.com

exception `geolocate.classes.arguments.` `NoFunctionAssignedToArgument`(argument)

  Bases: `Exception`

  User has given and argument that has no function assigned yet.

  `__init__`(argument)

`geolocate.classes.arguments.` `parse_arguments`()

`geolocate.classes.arguments.` `process_optional_parameters`(arguments)

  Take all optional arguments given by user and run one by one all functions assigned to each of them.

  Parameters: | arguments (Namespace) – Arguments object returned by ArgumentParser.parse_args()
  Returns: | None

`geolocate.classes.arguments.` `reset_locators_preference`()

  Sets back locators list to it’s default value.

  Returns: | None

`geolocate.classes.arguments.` `set_locators_preference`(arguments)

  Change locators list with new list given in arguments.

  Parameters: | arguments (Namespace) – Arguments object returned by ArgumentParser.parse_args()
  Returns: | None

`geolocate.classes.arguments.` `set_password`(arguments)

  Set password for webservice database access.

  Parameters: | arguments (Namespace) – Arguments object returned by ArgumentParser.parse_args()
  Returns: | None

`geolocate.classes.arguments.` `set_user`(arguments)

  Set user for webservice database access.

  Parameters: | arguments (Namespace) – Arguments object returned by ArgumentParser.parse_args()
  Returns: | None

`geolocate.classes.arguments.` `show_disabled_locators`()

  Print in console enabled locators ordered by preference.

  Returns: | None

`geolocate.classes.arguments.` `show_enabled_locators`()

  Print in console enabled locators ordered by preference.

  Returns: | None

`geolocate.classes.arguments.` `show_password`()

  Print on console password configured for webservice database access.

  Returns: | None

`geolocate.classes.arguments.` `show_user`()

  Print on console user configured for webservice database access.

  Returns: | None